shadowsocks-gtk
===============

A ShadowSocks Client written with python-twisted and pygtk.

![Screenshot](https://raw.github.com/apporc/shadowsocks-gtk/master/screenshot.png)

Requirements installation on Debian/Ubuntu/LinuxMint:  
sudo apt-get python-twisted-core python-gtk2 python-m2crypto

How to use:  
Double-click shadowsocks-gtk.py
